==> nextcloud-app-calendar-1%3A2.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Calendar" : "Kalendar",
    "Today" : "Sot",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "List" : "List",
    "Download" : "Shkarkoje",
    "Delete" : "Fshije",
    "Share link" : "Ndani lidhjen",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "can edit" : "mund të përpunojnë",
    "New calendar" : "Kalendar i ri",
    "Filename" : "Emri i skedarit",
    "Cancel" : "Anuloje",
    "Automatic" : "Automatike",
    "Actions" : "Veprimet",
    "Show week numbers" : "Shfaq numra javësh",
    "Settings & import" : "Konfigurimet dhe importi",
    "Notification" : "Njoftim",
    "Email" : "Emaili",
    "Unknown" : "I/E panjohur",
    "All day" : "Gjithë ditën",
    "never" : "kurrë",
    "after" : "pas",
    "Repeat" : "Përsërite",
    "Monday" : "E hënë",
    "Summary" : "Përmbledhje",
    "More" : "Më tepër",
    "Save" : "Ruaj",
    "Update" : "Përditësoje",
    "Personal" : "Personale",
    "Details" : "Detajet",
    "Attendees" : "Pjesëmarrës",
    "Reminders" : "Kujtues",
    "Close" : "Mbylle",
    "Anniversary" : "Përvjetor",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Status" : "Status",
    "Confirmed" : "E konfirmuar",
    "Tentative" : "Tentativë",
    "Categories" : "Kategoritë",
    "Presentation" : "Paraqitje",
    "Office" : "Zyrë",
    "Mail" : "Posta",
    "Global" : "Globale"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.4.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Calendar" : "Kalendar",
    "Today" : "Sot",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "List" : "List",
    "Download" : "Shkarkoje",
    "Delete" : "Fshije",
    "Share link" : "Ndani lidhjen",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "can edit" : "mund të përpunojnë",
    "New calendar" : "Kalendar i ri",
    "Filename" : "Emri i skedarit",
    "Cancel" : "Anuloje",
    "Automatic" : "Automatike",
    "Actions" : "Veprimet",
    "Show week numbers" : "Shfaq numra javësh",
    "Settings & import" : "Konfigurimet dhe importi",
    "Notification" : "Njoftim",
    "Email" : "Emaili",
    "Unknown" : "I/E panjohur",
    "All day" : "Gjithë ditën",
    "Repeat" : "Përsërite",
    "Save" : "Ruaj",
    "never" : "kurrë",
    "after" : "pas",
    "Monday" : "E hënë",
    "More" : "Më tepër",
    "Update" : "Përditësoje",
    "Global" : "Globale",
    "Personal" : "Personale",
    "Details" : "Detajet",
    "Attendees" : "Pjesëmarrës",
    "Close" : "Mbylle",
    "Anniversary" : "Përvjetor",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Status" : "Status",
    "Confirmed" : "E konfirmuar",
    "Tentative" : "Tentativë",
    "Categories" : "Kategoritë",
    "Presentation" : "Paraqitje",
    "Office" : "Zyrë",
    "Mail" : "Posta"
},
"nplurals=2; plural=(n != 1);");
